@@ -21,6 +21,8 @@
  *  Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
 #include "gtkhtml.h"
 #include "htmlengine.h"
 #include "htmlobject.h"
@@ -29,7 +31,7 @@
 #include "paragraph.h"
 #include "utils.h"
 #include "text.h"
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 static void gtk_html_a11y_class_init (GtkHTMLA11YClass *klass);
 static void gtk_html_a11y_init       (GtkHTMLA11Y *a11y);
